@@ -5,7 +5,9 @@
 #' is primarily limited to helping function examples.
 #' @param n `(integer(1))` \cr Number of samples
 #' @param trt,age,sex `(numeric(1))` \cr Coefficients for covariates.
-#' @param cutoff `(numeric(1))` \cr Cutoff for determining Type I censoring.
+#' @param cutoff `(numeric(1))` \cr Deprecated, in future use `cens`.
+#' @param cens `(numeric(1))` \cr Proportion of censoring to be generated, cut-off time is then
+#' selected as the quantile that results in `cens`.
 #'
 #' @return
 #' [data.frame()]
@@ -14,7 +16,12 @@
 #' simsurvdata()
 #'
 #' @export
-simsurvdata <- function(n = 100, trt = 2, age = 2, sex = 1.5, cutoff = 20) {
+simsurvdata <- function(n = 100, trt = 2, age = 2, sex = 1.5, cutoff = NULL, cens = 0.3) {
+
+  if (!is.null(cutoff)) {
+    stop("`cutoff` is now deprecated, in the future please use `cens`.")
+  }
+
   covs <- data.frame(
     sexF = stats::rbinom(n, 1, 0.5),
     age = round(stats::runif(n, 20, 50)),
@@ -25,7 +32,10 @@ simsurvdata <- function(n = 100, trt = 2, age = 2, sex = 1.5, cutoff = 20) {
   shape <- age * covs$age
 
   time <- stats::rweibull(nrow(covs), shape = shape, scale = scale)
-  time <- ((time - min(time)) / (max(time) - min(time)) * 29) + 1
+
+  if (is.null(cutoff)) {
+    cutoff <- as.numeric(stats::quantile(time, 1 - cens))
+  }
 
   status <- as.integer(time <= cutoff)
   time[time > cutoff] <- cutoff
